package com.ruoyi.tool.service;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.tool.domain.TUnifyFile;
import org.springframework.web.multipart.MultipartFile;

/**
 * 附件Service接口
 * 
 * @author ruoyi
 * @date 2024-02-23
 */
public interface ITUnifyFileService 
{
    /**
     * 查询附件
     * 
     * @param id 附件主键
     * @return 附件
     */
    public TUnifyFile selectTUnifyFileById(String id);

    /**
     * 查询附件列表
     * 
     * @param tUnifyFile 附件
     * @return 附件集合
     */
    public List<TUnifyFile> selectTUnifyFileList(TUnifyFile tUnifyFile);

    /**
     * 新增附件
     * 
     * @param tUnifyFile 附件
     * @return 结果
     */
    public int insertTUnifyFile(TUnifyFile tUnifyFile);

    /**
     * 批量新增关联附件
     * @param tUnifyFileList
     * @param fileId
     * @param fileBusinessId
     * @param uploadType
     * @param createBy
     * @return
     */
    public void insertTUnifyFileList(List<TUnifyFile> tUnifyFileList,String fileId,String fileBusinessId,String uploadType,String createBy);
    /**
     * 批量新增关联附件
     * @param tUnifyFileList
     * @param projectPoolId
     * @param fileBusinessId
     * @param uploadType
     * @param createBy
     * @return
     */
    public void insertTUnifyFileLists(List<TUnifyFile> tUnifyFileList,String projectPoolId,String fileBusinessId,String uploadType,String createBy,String fileType,String projectStage);
    /**
     * 修改附件
     * 
     * @param tUnifyFile 附件
     * @return 结果
     */
    public int updateTUnifyFile(TUnifyFile tUnifyFile);

    /**
     * 批量删除附件
     * 
     * @param ids 需要删除的附件主键集合
     * @return 结果
     */
    public int deleteTUnifyFileByIds(String[] ids);

    /**
     * 删除附件信息
     * 
     * @param id 附件主键
     * @return 结果
     */
    public int deleteTUnifyFileById(String id);

    /**
     * 批量删除附件
     *
     * @param ids
     * @return
     */
    public int updateTUnifyFileByIds(String[] ids);

    /**
     * 批量删除附件
     *
     * @param fileBusinessIds
     * @return
     */
    public int updateTUnifyFileBusinessIds(String[] fileBusinessIds);

    /**
     * 根据附件业务ID()获取附件详情信息列表
     *
     * @param fileBusinessId
     * @param uploadType
     * @return
     */
    public List<TUnifyFile> selectTUnifyFileByBusinessIdList(String fileBusinessId,String uploadType);
    /**
     * 根据ID()获取附件详情信息列表
     *
     * @param id
     * @param uploadType
     * @return
     */
    public List<TUnifyFile> selectTUnifyFileByIdList(String id,String uploadType);

    /**
     * 根据fileId()获取项目中所有附件列表
     * @param fileId
     * @return
     */
    List<TUnifyFile> listFileId(String fileId);
}
